@@ -564,11 +564,14 @@ mxCheckIdentification <- function(model, details=TRUE){
 	theParams <- omxGetParameters(model)
 	jac <- omxManifestModelByParameterJacobian(model)
 	if(imxHasConstraint(model)){
+    # Better if there was a separate compute step to estimate the constraintJacobian
 		tmpModel <- mxModel(model, mxComputeSequence(list(mxComputeNumericDeriv(hessian=FALSE), mxComputeReportDeriv())))
 		tmpModel <- mxRun(tmpModel, silent=TRUE)
 		cjac <- tmpModel$output$constraintJacobian
 		# drop model name from constraint name
-		rownames(cjac) <- sapply(strsplit(rownames(cjac), fixed=TRUE, split=imxSeparatorChar), '[', 2)
+		if(length(rownames(cjac))){
+			rownames(cjac) <- sapply(strsplit(rownames(cjac), fixed=TRUE, split=imxSeparatorChar), '[', 2)
+		}
 	} else {
 		cjac <- matrix(, nrow=0, ncol=length(theParams))
 		colnames(cjac) <- names(theParams)
