@@ -1,5 +1,5 @@
 /*
- *  Copyright 2007-2020 by the individuals mentioned in the source code history
+ *  Copyright 2007-2021 by the individuals mentioned in the source code history
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -19,8 +19,8 @@
 #include "Compute.h"
 #include "EnableWarnings.h"
 
-class omxLISRELExpectation : public omxExpectation {
-	typedef omxExpectation super;
+class omxLISRELExpectation : public MVNExpectation {
+	typedef MVNExpectation super;
 	std::vector<int> exoDataColumns; // index into omxData
 	int verbose;
 	int numExoPred;
@@ -56,6 +56,7 @@ public:
 	virtual void populateAttr(SEXP expectation) override;
 	virtual omxMatrix *getComponent(const char*) override;
 	virtual void getExogenousPredictors(std::vector<int> &out) override;
+  virtual int numLatentVars() const override { return PS->cols; }
 
 	void studyExoPred();
 };
@@ -137,12 +138,7 @@ omxLISRELExpectation::~omxLISRELExpectation()
 
 void omxLISRELExpectation::populateAttr(SEXP algebra)
 {
-	auto oo = this;
-
-  {
-    ProtectedSEXP RnumStat(Rf_ScalarReal(omxDataDF(oo->data)));
-    Rf_setAttrib(algebra, Rf_install("numStats"), RnumStat);
-  }
+  super::populateAttr(algebra);
 
 	MxRList out;
   populateNormalAttr(algebra, out);
@@ -554,7 +550,7 @@ void omxLISRELExpectation::init()
 
 
 	cov = omxNewMatrixFromSlotOrAnon(rObj, currentState, "expectedCovariance", ntotal, ntotal);
-	if (!cov->hasMatrixNumber) covOwner = omxMatrixPtr(cov);
+	if (!cov->hasMatrixNumber) covOwner = cov;
 	else connectMatrixToExpectation(cov, this, "covariance");
 
 	LISobj->args = (omxMatrix**) R_alloc(2, sizeof(omxMatrix*));
@@ -562,7 +558,7 @@ void omxLISRELExpectation::init()
 	/* Means */
 	if(LISobj->TX != NULL || LISobj->TY != NULL || LISobj->KA != NULL || LISobj->AL != NULL) {
 		means = omxNewMatrixFromSlotOrAnon(rObj, currentState, "expectedMean", 1, ntotal);
-		if (!means->hasMatrixNumber) meanOwner = omxMatrixPtr(means);
+		if (!means->hasMatrixNumber) meanOwner = means;
 		else connectMatrixToExpectation(means, this, "mean");
 	} else LISobj->means  = 	NULL;
 	//TODO: Adjust means processing to allow only Xs or only Ys
